@@ -3719,5 +3719,9 @@ def submit(port, host='127.0.0.1',  db=0):
 		r.hset('dict:word_level', w, 'gsl2')
 	print(">> finished loading gsl2")
 
-if __name__ == '__main__':
-	submit(6311)
\ No newline at end of file
+def save_tsv():
+	with open('gsl2.tsv','w') as fw: 
+		[ fw.write(f"{w}\n") for w in word_gsl2]
+
+if __name__ == '__main__': 
+	save_tsv()
\ No newline at end of file
