@@ -35,8 +35,7 @@ async def getdata(fname:str="first name", lname:str="last name"):
 
 def run(port, reload:bool=False): 
 	''' python3 __main__.py 8000 --reload true '''
-	#uvicorn.run(app, host='0.0.0.0', port=port, reload=reload)
-	uvicorn.run("__main__:app", host='0.0.0.0', port=port, reload=reload)
+	uvicorn.run("__main__:app", host='0.0.0.0', port=port, reload=reload) 	#uvicorn.run(app, host='0.0.0.0', port=port, reload=reload)
 
 if __name__ == '__main__':
 	import fire
